@@ -52,6 +52,15 @@ if __name__ == '__main__':
     parser_jobs.add_argument('name', const='generate', nargs='?')
     parser_jobs.set_defaults(which='jobs')
 
+    parser_memorystore = subparsers.add_parser('memorystore', help='generate a redis memorystor')
+    parser_memorystore.add_argument(
+        'action',
+        const='generate',
+        nargs='?',
+        choices=['init']
+    )
+    parser_memorystore.set_defaults(which='memorystore')
+
     args = parser.parse_args()
     if len(sys.argv) == 1:
         parser.print_help(sys.stderr)
