@@ -36,20 +36,6 @@ class StepDeleteDir(Step):
         shutil.rmtree(self.path)
 
 
-class StepCommand(Step):
-    def __init__(self, command: List[str], **kwargs):
-        self.command = command
-        self.work_dir = kwargs.get('work_dir')
-
-    def run(self, config: Config, simulate: bool = False):
-        print('+ Run command:')
-        print(" ".join(self.command))
-        if not simulate:
-            p = subprocess.run(self.command, stdout=subprocess.PIPE, cwd=self.work_dir)
-            if p.returncode != 0:
-                raise exceptions.CommandError('command not success')
-
-
 class StepCopyFileContent(Step):
     def __init__(self, file_a_path: str, file_b_path: str):
         self.file_a_path = file_a_path
